[FFmpeg-cvslog] r12101 - trunk/libavfilter/avfilter.h

vitor subversion
Fri Feb 15 23:14:03 CET 2008


Author: vitor
Date: Fri Feb 15 23:14:02 2008
New Revision: 12101

Log:
Rename avfilter_create to avfilter_open and remove the wrapper function
avfilter_create_by_name.

Commited in SoC by Bobby Bingham on 2007-08-17 23:39:55


Modified:
   trunk/libavfilter/avfilter.h

Modified: trunk/libavfilter/avfilter.h
==============================================================================
--- trunk/libavfilter/avfilter.h	(original)
+++ trunk/libavfilter/avfilter.h	Fri Feb 15 23:14:02 2008
@@ -370,9 +370,10 @@ void avfilter_init(void);
 void avfilter_uninit(void);
 
 /**
  * Register a filter.  This is only needed if you plan to create an instance of
  * this filter by name later with avfilter_create_by_name.  A filter can still
  * by created with acfilter_create even if it is not registered.
  * @param filter The filter to register
  */
 void avfilter_register(AVFilter *filter);
@@ -391,15 +392,7 @@ AVFilter *avfilter_get_by_name(char *nam
  * @param inst_name Name to give to the new instance.  Can be NULL for none.
  * @return          Pointer to the new instance on success.  NULL on failure.
  */
-AVFilterContext *avfilter_create(AVFilter *filter, char *inst_name);
-
-/**
- * Creates a filter instace
- * @param name      The name of the filter type which is to be instantiated
- * @param inst_name Name to give to the new instance.  Can be NULL for none.
- * @return          Pointer to the new instance on success.  NULL in failure.
- */
-AVFilterContext *avfilter_create_by_name(char *name, char *inst_name);
+AVFilterContext *avfilter_open(AVFilter *filter, char *inst_name);
 
 /**
  * Initialize a filter
@@ -370,9 +370,10 @@ void avfilter_init(void);
 
 /**
- * Register a filter.  This is only needed if you plan to create an instance of
- * this filter by name later with avfilter_create_by_name.  A filter can still
- * by created with acfilter_create even if it is not registered.
+ * Register a filter.  This is only needed if you plan to use
+ * avfilter_get_by_name later to lookup the AVFilter structure by name. A
+ * filter can still by instantiated with avfilter_open even if it is not
+ * registered.
  * @param filter The filter to register
  */




More information about the ffmpeg-cvslog mailing list